#! /bin/sh
set -e

# Set the variables below to fit your site. You can then use cron to have this
# script run daily to automatically update your copy of the archive
#
# TO is the destination for the base of the Debian web directory (the dir that
# holds debian.org and debian.org-local)
#
# RSYNC_HOST is the site you have chosen from the mirrors file
#
# RSYNC_DIR is the directory given in the Archive-rsync: line of the
# mirrors file for the site you have chosen to mirror.
#
# chmod 744 anonwebsync
#
# You MUST have rsync 2.0.16-1 or newer which is available in slink

# This exclude should work quite well
#EXCLUDE="--exclude .glbuild* --exclude core --exclude \
#   .mhonarc.db --exclude *~ --exclude #*"

umask 022

TO=/mirror/www.debian.cz/debian
RSYNC_HOST=www.debian.cz
RSYNC_DIR=debian/
EXCLUDE=
LOG=/var/log/rsync/rsync.log

LOCK="${TO}/Archive-Update-in-Progress-`hostname -f`"

# Get in the right directory and set the umask to be group writable
# 
cd $HOME
umask 002

# Check to see if another sync is in progress
if lockfile -! -l 43200 -r 0 "$LOCK"; then
  echo `hostname` is unable to start rsync, lock file exists
  exit 1
fi
trap "rm -f $LOCK > /dev/null 2>&1" exit  

set +e
date >$LOG
rsync -rltvz --safe-links --delete \
     --exclude "Archive-Update-in-Progress-`hostname -f`" \
     --exclude "Archive-Update-in-Progress-*" \
     $EXCLUDE \
     $RSYNC_HOST::$RSYNC_DIR $TO >>$LOG 2>&1
savelog -c 30 $LOG >/dev/null

date -u > "${TO}/project/trace/`hostname -f`"

rm -f $LOCK
