#!/usr/bin/python

import string
import sys
import re

err_nomore_pkg="nomore_pkg"
err_diff_names="diff_names"
err_missing="missing"

class Package:
	REGEX_PACKAGE_NAME='(?s)Package: (.*?)\n'
	REGEX_PACKAGE_DESC='(?s)Description:((?: .*?\n)+)'
	REGEX_PACKAGE_VER ='(?s)Version: (.*?)\n'

	TRANSLATED   = 1
	UNTRANSLATED = 0

	__compre_name = re.compile(REGEX_PACKAGE_NAME)
	__compre_ver  = re.compile(REGEX_PACKAGE_VER)
	__compre_desc = re.compile(REGEX_PACKAGE_DESC)

	def __init__(self,data_string):
		self.__data=data_string
		self.__translated = self.UNTRANSLATED
		self.__searchre_name = self.__compre_name.search(self.__data)
		self.__searchre_ver  = self.__compre_ver.search (self.__data)
		self.__searchre_desc = self.__compre_desc.search(self.__data)
	def name(self):
		if self.__searchre_name:
			return self.__searchre_name.group(1)
		else: 
			return None 
    	def version(self):
 		if self.__searchre_ver:
			return self.__searchre_ver.group(1)
		else: 
			return None 
     	def description(self):
 		if self.__searchre_desc:
			return self.__searchre_desc.group(1)
		else: 
			return None
	def translate(self,tra_desc):
 		if self.__searchre_desc:
			self.__data = self.__compre_desc.sub('Description:'+tra_desc,self.__data)
			self.__translated = self.TRANSLATED
			self.__searchre_name = self.__compre_name.search(self.__data)
			self.__searchre_ver  = self.__compre_ver.search (self.__data)
			self.__searchre_desc = self.__compre_desc.search(self.__data)
	def write(self):
		if not self.__translated:
			sys.stderr.write('<'+self.name()+' '+self.version()+'> untranslated, flushing original\n')
		sys.stdout.write(self.__data)

	def errdump(self):
		sys.stderr.write(self.__data)

def readpackage(file):
	s=''
	while 1:
        	line=file.readline()
        	if not string.strip(line):
			if string.strip(s):
				return Package(s)
			elif not line:
				return None
			else:
				s=''
		else:
		   s=s+line

def readpackages(file):
	i=1
	hash = {}
	while 1:
		p=readpackage(file)
		if not p:
			return hash
		if not (p.name() and p.version() and p.description()):
			p.errdump()
			raise err_missing
		key=p.name()+'#'+p.version()
		if hash.has_key(key):
		    sys.stderr.write('<warning: '+p.name()+' '+p.version()+' more than once\n')
		else:
		    hash[key]=(i,p)
		    i=i+1

if __name__ == '__main__':
	try:
		forg = open(sys.argv[1:2][0], 'r')
		packages=readpackages(forg)
		
		flang1=open(sys.argv[2:3][0], 'r')
		flang2=open(sys.argv[3:4][0], 'r')
		try:
			while 1:
				p1=readpackage(flang1)
				p2=readpackage(flang2)
				if not p1 and not p2:
					raise err_nomore_pkg
				elif not p1 or not p2:
					raise err_missing
				if not (p1.name() and p1.version() and p1.description()):
					p1.errdump()
					raise err_missing
				if not (p2.name() and p2.version() and p2.description()):
					p2.errdump()
					raise err_missing
				elif p1.name()!=p2.name() or p1.version()!=p2.version():
					p1.errdump()
					sys.stderr.write('------------------\n')
					p2.errdump()
					raise err_diff_names
				try:
					(i,p)=packages[p1.name()+'#'+p1.version()]
					"""if p.description()==p1.description():"""
					p.translate(p2.description())
					"""else: """
					"""    sys.stderr.write('diff en desc:'+p.name+' '+p.version()+'\n')"""
				except KeyError:
					pass
		except err_nomore_pkg:
			pass
		list=packages.values()
		list.sort()
		for c in list:
			(n,p)=c
			p.write()
			sys.stdout.write('\n')

	except IOError, msg:
		sys.stderr.write('<abort: input problem>\n')
	except err_missing:
		sys.stderr.write('<abort: missing one of name, version, description part>\n')
	except err_diff_names:
		sys.stderr.write('<abort: diffrent packages>\n')
								


